Name:           icu4j
Version:        54.1.1
Release:        %mkrel 8
Group:          Development/Java
Epoch:          1
Summary:        International Components for Unicode for Java
License:        MIT and EPL
URL:            http://site.icu-project.org/

#CAUTION
#to create a tarball use following procedure
#svn co http://source.icu-project.org/repos/icu/icu4j/tags/release-54-1-1 icu4j-<version>
#tar caf icu4j-<version>.tar.xz icu4j-<version>/
Source0:        icu4j-%{version}.tar.xz

# Java 8 taglet API changes
Patch0:         java8-taglets.patch

# Add better OSGi metadata to core jar
Patch1:         improve-osgi-manifest.patch

BuildRequires:  ant
BuildRequires:  java-javadoc
BuildRequires:  javapackages-local
BuildRequires:  zip

# Obsoletes/provides added in F22
Obsoletes:      %{name}-eclipse < %{epoch}:%{version}-%{release}
Provides:       %{name}-eclipse = %{epoch}:%{version}-%{release}

BuildArch:      noarch

%description
The International Components for Unicode (ICU) library provides robust and
full-featured Unicode services on a wide variety of platforms. ICU supports
the most current version of the Unicode standard, and provides support for
supplementary characters (needed for GB 18030 repertoire support).

Java provides a very strong foundation for global programs, and IBM and the
ICU team played a key role in providing globalization technology into Sun's
Java. But because of its long release schedule, Java cannot always keep
up-to-date with evolving standards. The ICU team continues to extend Java's
Unicode and internationalization support, focusing on improving
performance, keeping current with the Unicode standard, and providing
richer APIs, while remaining as compatible as possible with the original
Java text and internationalization API design.

%package charset
Summary:        Charset converter library of %{name}
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description charset
Charset converter library of %{name}.

%package localespi
Summary:        Locale SPI library of %{name}
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description localespi
Locale SPI library of %{name}.

%package javadoc
Summary:        Javadoc for %{name}
Requires:       java-javadoc

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n icu4j-%{version}

%patch0
%patch1

%build
export JAVA_HOME=%{_jvmdir}/java/
ant -Dicu4j.api.doc.jdk.link=%{_javadocdir}/java all check

%mvn_artifact pom.xml icu4j.jar

%install
%mvn_install -J doc

# No poms for these, so install manually
install -m 644 icu4j-charset.jar   %{buildroot}%{_javadir}/icu4j/
install -m 644 icu4j-localespi.jar %{buildroot}%{_javadir}/icu4j/

%files -f .mfiles
%doc main/shared/licenses/license.html readme.html APIChangeReport.html
%dir %{_javadir}/icu4j
%dir %{_mavenpomdir}/icu4j

%files charset
%doc main/shared/licenses/license.html
%{_javadir}/icu4j/icu4j-charset.jar

%files localespi
%doc main/shared/licenses/license.html
%{_javadir}/icu4j/icu4j-localespi.jar

%files javadoc -f .mfiles-javadoc
%doc main/shared/licenses/license.html




%changelog
* Wed Mar 02 2016 neoclust <neoclust> 1:54.1.1-8.mga6
+ Revision: 982334
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 1:54.1.1-7.mga6
+ Revision: 977216
- First rebuild of the java stack
- sync package icu4j with fedora

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Fri Jul 03 2015 daviddavid <daviddavid> 1:54.1.1-1.mga6
+ Revision: 849709
- sync with fc23 (update to 54.1.1)
  * Remove incomplete SCL macros
  * Drop unnecessay requires on main package and fix requires on sub packages
  * Drop the eclipse sub-package, no longer needed
  * Add patch for building against java 8 taglet API
  * Fixes: rhbz#1087450, rhbz#1106794
  * Add patch for generating better OSGi metadata in core lib
  * Install core lib with mvn_install
  * Package localespi lib
  * Run test suite

* Thu Jan 01 2015 pterjan <pterjan> 1:52.1-2.mga5
+ Revision: 807952
- Fix groups
- Clean rebuild
- Clean rebuild
- Clean rebuild
- Clean rebuild
- Get back closer to Fedora 21 with only the build fixes
- Sync with Fedora (not 21 as it is very broken and was fixed since)
- Restore

  + sander85 <sander85>
    - Depends on broken java stack

  + umeabot <umeabot>
    - Second Mageia 5 Mass Rebuild
    - Mageia 5 Mass Rebuild

* Mon Oct 21 2013 umeabot <umeabot> 1:50.1.1-3.mga4
+ Revision: 537213
- Mageia 4 Mass Rebuild

* Thu Sep 26 2013 dmorgan <dmorgan> 1:50.1.1-2.mga4
+ Revision: 486591
- Rebuild against bootstrap rpm
- New version

* Mon Jul 15 2013 dmorgan <dmorgan> 1:50.1.0-1.mga4
+ Revision: 454847
- Update to version 50.1.0
- New version

* Sat Jan 12 2013 umeabot <umeabot> 1:4.4.2.2-13.mga3
+ Revision: 354227
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jun 29 2012 dmorgan <dmorgan> 1:4.4.2.2-12.mga3
+ Revision: 265210
- New version 4.4.2.2

* Mon Jan 09 2012 dmorgan <dmorgan> 1:4.4.2-5.mga2
+ Revision: 194263
- Add OSGi manifest for bootstrapping Eclipse

* Sun Dec 25 2011 dmorgan <dmorgan> 1:4.4.2-4.mga2
+ Revision: 187558
- Rebuild for OSGi provides.

* Sat Sep 17 2011 dmorgan <dmorgan> 1:4.4.2-3.mga2
+ Revision: 144346
- Fix file list
- Fix build w/o extra
- Disable extra for now
- Fix javadoc version requires
- Add back extra package

* Tue Jul 19 2011 dmorgan <dmorgan> 1:4.4.2-1.mga2
+ Revision: 126838
- New version 4.4.2
- Bump release to allow eclipse install

  + gil <gil>
    - add sub package extra (icu4j-charsets is required by apache harmony)
    - add sub package extra (icu4j-charsets is required by apache harmony)

* Fri Feb 11 2011 dmorgan <dmorgan> 1:4.2.1-0.2.6.mga1
+ Revision: 49988
- Fix file list
- Bump release
- Build with eclipse

* Sun Jan 16 2011 dmorgan <dmorgan> 1:4.2.1-0.2.5.mga1
+ Revision: 20284
- Update to version 4.2.1 ( sync with fedora)

* Sun Jan 16 2011 dmorgan <dmorgan> 1:3.8.1-0.2.5.mga1
+ Revision: 20267
- Fix build w/o eclipse
- imported package icu4j


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 1:3.8.1-0.2.5mdv2011.0
+ Revision: 605968
- rebuild

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 1:3.8.1-0.2.4mdv2010.1
+ Revision: 522920
- rebuilt for 2010.1

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 1:3.8.1-0.2.3mdv2010.0
+ Revision: 425328
- rebuild

  + Jérôme Soyer <saispo@mandriva.org>
    - Readd Eclipse build

* Thu Jan 29 2009 Jérôme Soyer <saispo@mandriva.org> 1:3.8.1-0.2.1mdv2009.1
+ Revision: 335225
- Build without Eclipse for downgrading it
- Add Patch
- Rewind to the previous version
- Backward to previous version for Eclipse working

* Wed Jan 21 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 0:4.0.1-0.0.1mdv2009.1
+ Revision: 332064
- update to new version 4.0.1
- drop patches 2 and 3
- spec file clean

  + Alexander Kurtakov <akurtakov@mandriva.org>
    - move the eclipse bits to %%_libdir/eclipse

* Thu Jul 17 2008 Alexander Kurtakov <akurtakov@mandriva.org> 0:3.8.1-0.2.1mdv2009.0
+ Revision: 237782
- new version 3.8.1

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

  + Anssi Hannula <anssi@mandriva.org>
    - buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)

* Sat Nov 24 2007 David Walluck <walluck@mandriva.org> 0:3.6.1-1.6.1mdv2008.1
+ Revision: 111814
- fix BuildRequires
- sync with latest fc9

* Sat Sep 15 2007 Anssi Hannula <anssi@mandriva.org> 0:3.6.1-1.2.2mdv2008.0
+ Revision: 87390
- rebuild to filter out autorequires of GCJ AOT objects
- remove unnecessary Requires(post) on java-gcj-compat

* Fri Jul 27 2007 David Walluck <walluck@mandriva.org> 0:3.6.1-1.2.1mdv2008.0
+ Revision: 56202
- 3.6.1


* Tue Oct 31 2006 David Walluck <walluck@mandriva.org> 3.4.5-1mdv2007.0
+ Revision: 74076
- 3.4.5
- Import icu4j

* Mon Jul 10 2006 David Walluck <walluck@mandriva.org> 0:3.4.4-2mdv2007.0
- use JPackage spec
- license is MIT

* Sun Jul 09 2006 David Walluck <walluck@mandriva.org> 0:3.4.4-1mdv2007.0
- release

* Mon Feb 27 2006 Fernando Nasser <fnasser@redhat.com> - 0:3.2-2jpp
- First JPP 1.7 build

* Sat Jan 29 2005 David Walluck <david@jpackage.org> 0:3.2-1jpp
- release (contributed by Mary Ellen Foster <mefoster at gmail.com>)

